@@ -26,15 +26,15 @@
 ##' age <- age_calc(a, as.Date('2005-09-01'))
 ##' age
 age_calc <- function(dob, enddate=Sys.Date(), units='months', precise=TRUE){
-  if (!inherits(dob, "Date") | !inherits(enddate, "Date")){
+  if (!inherits(dob, "Date") | !inherits(enddate, "Date")) {
     stop("Both dob and enddate must be Date class objects")
   }
-  if(any(enddate < dob)){
+  if (any(enddate < dob)) {
     stop("End date must be a date after date of birth")
   }
   start <- as.POSIXlt(dob)
   end <- as.POSIXlt(enddate)
-  if(precise){
+  if (precise) {
     start_is_leap <- ifelse(start$year %% 400 == 0, TRUE, 
                             ifelse(start$year %% 100 == 0, FALSE,
                                    ifelse(start$year %% 4 == 0, TRUE, FALSE)))
@@ -42,24 +42,24 @@ age_calc <- function(dob, enddate=Sys.Date(), units='months', precise=TRUE){
                           ifelse(end$year %% 100 == 0, FALSE,
                                  ifelse(end$year %% 4 == 0, TRUE, FALSE)))
   }
-  if(units=='days'){
-    result <- difftime(end, start, units='days')
-  }else if(units=='months'){
-    months <- sapply(mapply(seq, as.POSIXct(start), as.POSIXct(end), 
-                            by='months', SIMPLIFY=FALSE), 
-                     length) - 1
+  if (units == 'days') {
+    result <- difftime(end, start, units = 'days')
+  } else if (units == 'months') {
+    months <- vapply(mapply(seq, as.POSIXct(start), as.POSIXct(end), 
+                            by = 'months', SIMPLIFY = FALSE), 
+                     length, FUN.VALUE = length(start)) - 1
     # length(seq(start, end, by='month')) - 1
-    if(precise){
-      month_length_end <- ifelse(end$mon==1 & end_is_leap, 29,
-                                 ifelse(end$mon==1, 28, 
+    if (precise) {
+      month_length_end <- ifelse(end$mon == 1 & end_is_leap, 29,
+                                 ifelse(end$mon == 1, 28, 
                                         ifelse(end$mon %in% c(3, 5, 8, 10), 
                                                30, 31)))
-      month_length_prior <- ifelse((end$mon-1)==1 & start_is_leap, 29, 
-                                   ifelse((end$mon-1)==1, 28, 
-                                        ifelse((end$mon-1) %in% c(3, 5, 8, 10), 
+      month_length_prior <- ifelse((end$mon - 1) == 1 & start_is_leap, 29, 
+                                   ifelse((end$mon - 1) == 1, 28, 
+                                        ifelse((end$mon - 1) %in% c(3, 5, 8, 10), 
                                                  30, 31)))
       month_frac <- ifelse(end$mday > start$mday,
-                           (end$mday-start$mday)/month_length_end,
+                           (end$mday - start$mday) / month_length_end,
                            ifelse(end$mday < start$mday, 
                                   (month_length_prior - start$mday) / 
                                     month_length_prior + 
@@ -68,23 +68,23 @@ age_calc <- function(dob, enddate=Sys.Date(), units='months', precise=TRUE){
     }else{
       result <- months
     }
-  }else if(units=='years'){
-    years <- sapply(mapply(seq, as.POSIXct(start), as.POSIXct(end), 
-                           by='years', SIMPLIFY=FALSE), 
-                    length) - 1
-    if(precise){
+  } else if (units == 'years') {
+    years <- vapply(mapply(seq, as.POSIXct(start), as.POSIXct(end), 
+                           by = 'years', SIMPLIFY = FALSE), 
+                    length, FUN.VALUE = length(start)) - 1
+    if (precise) {
       start_length <- ifelse(start_is_leap, 366, 365)
       end_length <- ifelse(end_is_leap, 366, 365)
       start_day <- ifelse(start_is_leap & start$yday >= 60,
                           start$yday - 1,
                           start$yday)
-      end_day <- ifelse(end_is_leap & end$yday >=60,
+      end_day <- ifelse(end_is_leap & end$yday >= 60,
                         end$yday - 1,
                         end$yday)
       year_frac <- ifelse(start_day < end_day,
                           (end_day - start_day)/end_length,
                           ifelse(start_day > end_day, 
-                                 (start_length-start_day) / start_length +
+                                 (start_length - start_day) / start_length +
                                    end_day / end_length, 0.0))
       result <- years + year_frac
     }else{
